<?php

namespace Drupal\mercury_editor_templates\Controller;

use Drupal;
use Drupal\Core\Controller\ControllerBase;
use Drupal\layout_paragraphs\LayoutParagraphsLayout;
use Drupal\layout_paragraphs\LayoutParagraphsComponent;
use Drupal\mercury_editor_templates\Entity\MeTemplate;

class SaveAsTemplate extends ControllerBase {

  /**
   * A Mercury Editor layout object.
   *
   * @var \Drupal\layout_paragraphs\LayoutParagraphsLayout
   */
  protected $layoutParagraphsLayout;

  /**
   * Save a paragraph entity as a template.
   *
   * @param \Drupal\paragraphs\Entity\Paragraph $entity
   *   The paragraph entity to save.
   *
   * @return array
   *   A render array.
   */
  public function templateForm(LayoutParagraphsLayout $layout_paragraphs_layout, string $uuid) {
    $this->layoutParagraphsLayout = $layout_paragraphs_layout;
    $duplicate_component = $this->layoutParagraphsLayout->duplicateComponent($uuid);
    $uuids = $this->getComponentUuids($duplicate_component);
    $field_content = [];
    foreach ($uuids as $uuid) {
      $field_content[] = [
        'entity' => $this->layoutParagraphsLayout->getComponentByUuid($uuid)->getEntity()
      ];
    }
    $me_template = MeTemplate::create([
      'content' => $field_content,
      'status' => TRUE,
    ]);
    $edit_form = \Drupal::entityTypeManager()->getFormObject('me_template', 'dialog')->setEntity($me_template);
    return \Drupal::formBuilder()->getForm($edit_form, $this->layoutParagraphsLayout);
  }

  protected function getComponentUuids(LayoutParagraphsComponent $component, $uuids = []) {
    $uuids[] = $component->getEntity()->uuid();
    if ($component->isLayout()) {
      $section = $this->layoutParagraphsLayout->getLayoutSection($component->getEntity());
      foreach ($section->getComponents() as $component) {
        $uuids += $this->getComponentUuids($component, $uuids);
      }
    }
    return $uuids;
  }

}

