<?php

namespace Drupal\mercury_editor\Ajax;

use Drupal\Core\Asset\AttachedAssets;
use Drupal\Core\Ajax\CommandInterface;
use Drupal\Core\Ajax\CommandWithAttachedAssetsInterface;

/**
 * Ajax command to dispatch a Mercury Editor Layout  Event.
 */
class DispatchEventCommand implements CommandInterface, CommandWithAttachedAssetsInterface {

  /**
   * The specific operation being performed in this update.
   *
   * @var string
   */
  protected $operation;

  /**
   * Additional event data.
   *
   * @var array
   */
  protected $data;

  /**
   * The event to dispatch.
   *
   * @var string
   */
  protected $eventName;

  /**
   * Selector for the HTML element to dispatch the event.
   *
   * @var string
   */
  protected $selector;

  /**
   * Constructor.
   */
  public function __construct($event_name, $selector, $operation, $data = []) {
    $this->eventName = $event_name;
    $this->selector = $selector;
    $this->operation = $operation;
    $this->data = $data;
  }

  /**
   * Render custom ajax command.
   *
   * @return array
   *   The command array.
   */
  public function render() {
    return [
      'command' => 'mercuryEditorEditTrayDispatchEvent',
      'eventName' => $this->eventName,
      'selector' => $this->selector,
      'operation' => $this->operation,
      'data' => $this->data,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getAttachedAssets() {
    $assets = new AttachedAssets();
    $assets->setLibraries(['mercury_editor/edit_screen.ajax']);
    return $assets;
  }

}
