<?php

namespace Drupal\mercury_editor\Routing;

use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\Routing\Route;

/**
 * Overrides node add routes for specific content types with ME tray enabled.
 */
class NodeAddRoutes {

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a new NodeAddRoutes object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * Provides node/add routes for edit tray -enabled content types.
   *
   * @return \Symfony\Component\Routing\Route[]
   */
  public function routes() {
    $routes = [];
    $content_types = $this->configFactory->get('mercury_editor.settings')->get('content_types') ?? [];
    foreach (array_keys($content_types) as $type) {
      $route = new Route(
        '/node/add/' . $type,
        [
          '_controller' => '\Drupal\mercury_editor\Controller\MercuryEditorController::createNode',
          '_title_callback' => '\Drupal\mercury_editor\Controller\MercuryEditorController::getTitle',
        ],
        [
          '_entity_create_access' => 'node:' . $type,
        ],
      );
      $route->setOption('no_cache', TRUE);
      $route->setOption('_mercury_editor_route', TRUE);
      $route->setOption('_hide_admin_toolbar', TRUE);
      $route->setOption('parameters', [
        'node_type' => [
          'type' => 'entity:node_type',
        ],
      ]);
      $route->setDefault('node_type', $type);
      $routes['node.add.' . $type] =  $route;
    }
    return $routes;
  }

}
