<?php

namespace Drupal\Tests\mercury_editor\FunctionalJavascript;

use Behat\Mink\Exception\ExpectationException;
use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
use Drupal\Tests\paragraphs\FunctionalJavascript\ParagraphsTestBaseTrait;
use Drupal\Tests\layout_paragraphs\FunctionalJavascript\BuilderTestBase as LayoutParagraphsBuilderTestBase;

/**
 * Base class for Layout Paragraphs Builder tests.
 *
 * @group layout_paragraphs
 */
abstract class BuilderTestBase extends LayoutParagraphsBuilderTestBase {

  use ParagraphsTestBaseTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'mercury_editor',
    'layout_paragraphs',
    'paragraphs',
    'node',
    'field',
    'field_ui',
    'block',
    'paragraphs_test',
  ];


  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->loginWithPermissions($this->adminPermissions);
    $this->drupalLogout();
  }

  /**
   * {@inheritdoc}
   */
  protected function addTextComponent($text, $css_selector) {
    $this->getSession()->switchToIFrame('me-preview');
    parent::addTextComponent($text, $css_selector);
  }

  /**
   * Inserts a text component by clicking the "+" button and choosing "section".
   *
   * @param int $columns_choice
   *   Which column option to choose.
   * @param string $css_selector
   *   A css selector targeting the "+" button.
   */
  protected function addSectionComponent(int $columns_choice, $css_selector) {
    $this->getSession()->switchToIFrame('me-preview');
    parent::addSectionComponent($columns_choice, $css_selector);
  }

  /**
   * Simulates pressing a key with javascript.
   *
   * @param string $key_code
   *   The string key code (i.e. ArrowUp, Enter).
   */
  protected function keyPress($key_code) {
    $script = 'var e = new KeyboardEvent("keydown", {bubbles : true, cancelable : true, code: "' . $key_code . '"});
    document.body.dispatchEvent(e);';
    $this->getSession()->executeScript($script);
  }

  /**
   * Enables the frontend builder formatter for a content type and field.
   */
  protected function useFrontEndBuilderFormatter($type, $field) {
    $this->loginWithPermissions($this->adminPermissions);
    $this->drupalGet('admin/structure/types/manage/' . $type . '/display');
    $page = $this->getSession()->getPage();
    $page->selectFieldOption('fields[' . $field . '][type]', 'layout_paragraphs_builder');
    $this->assertSession()->assertWaitOnAjaxRequest(10000, 'Unable to choose layout paragraphs builder (fields[' . $field . '][type]) field formatter.');
    $this->submitForm([], 'Save');
    $this->drupalLogout();
  }

  /**
   * Enables the frontend editor.
   */
  protected function enableFrontendBuilder() {
    $this->forceVisible('.lpb-enable-button');
    $this->getSession()->getPage()->find('css', '.lpb-enable-button')->click();
    $this->assertSession()->assertWaitOnAjaxRequest();
    $this->assertSession()->elementExists('css', '.layout-paragraphs-builder-form');
  }

  /**
   * Save the frontend builder.
   */
  protected function saveFrontendBuilder() {
    $page = $this->getSession()->getPage();
    $page->find('css', '.lpb-form__actions .button--primary')->click();
    $this->assertSession()->assertWaitOnAjaxRequest();
  }

  /**
   * Close the frontend builder.
   */
  protected function closeFrontendBuilder() {
    $page = $this->getSession()->getPage();
    $page->find('css', '.lpb-form__actions .lpb-btn--cancel')->click();
    $this->assertSession()->assertWaitOnAjaxRequest();
  }

  /**
   * Save and close the fronend builder.
   */
  protected function saveAndCloseFrontendBuilder() {
    $this->saveFrontendBuilder();
    $this->closeFrontendBuilder();
  }

}
